@@ -1,9 +1,9 @@
-#!/usr/bin/python2.7
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 from subprocess import Popen, PIPE, STDOUT
 from univention.management.console.config import ucr
-from univention.management.console.modules.diagnostic import Critical
+from univention.management.console.modules.diagnostic import Critical, MODULE
 
 from univention.lib.i18n import Translation
 _ = Translation('univention-management-console-module-diagnostic').translate
@@ -20,15 +20,20 @@ umc_modules = [{
 	'flavor': 'network'
 }]
 
+run_descr = ['This can be checked by running: ping "$(ucr get gateway)"']
+
 
 def run(_umc_instance):
 	ucr.load()
 	gateway = ucr.get('gateway')
 	if not gateway:
+		MODULE.error('There is no gateway configured.')
 		raise Critical(_('There is no gateway configured.'))
 	process = Popen(['/bin/ping', '-c3', '-w4', '-W4', gateway], stdout=PIPE, stderr=STDOUT)
 	stdout, stderr = process.communicate()
+	stdout = stdout.decode('UTF-8', 'replace')
 	if process.returncode:
+		MODULE.error('\n'.join(description))
 		raise Critical('\n'.join([description % (gateway,), '', stdout]))
 
 
